#######################################################
## .0. Mineral Abbreviations                     !!! ##
#######################################################
MINERAL_ABBREV_MAP: dict[str, dict[str, str]] = {
    "alm": {
        "name": "almandine",
        "group": "Garnets & olivines",
        "formula": "Fe3Al2Si3O12",
        "crystal_system": "",
        "other_info": "",
    },
    "andr": {
        "name": "andradite",
        "group": "Garnets & olivines",
        "formula": "Ca3Fe2Si3O12",
        "crystal_system": "",
        "other_info": "",
    },
    "gr": {
        "name": "grossular",
        "group": "Garnets & olivines",
        "formula": "Ca3Al2Si3O12",
        "crystal_system": "",
        "other_info": "",
    },
    "knor": {
        "name": "knorringite",
        "group": "Garnets & olivines",
        "formula": "Mg3Cr2Si3O12",
        "crystal_system": "",
        "other_info": "",
    },
    "maj": {
        "name": "majorite",
        "group": "Garnets & olivines",
        "formula": "Mg4Si4O12",
        "crystal_system": "",
        "other_info": "",
    },
    "py": {
        "name": "pyrope",
        "group": "Garnets & olivines",
        "formula": "Mg3Al2Si3O12",
        "crystal_system": "",
        "other_info": "",
    },
    "pyilm": {
        "name": "pyrope [ilmenite]",
        "group": "Garnets & olivines",
        "formula": "Mg3Al2Si3O12",
        "crystal_system": "",
        "other_info": "",
    },
    "spss": {
        "name": "spessartine",
        "group": "Garnets & olivines",
        "formula": "Mn3Al2Si3O12",
        "crystal_system": "",
        "other_info": "",
    },
    "chum": {
        "name": "clinohumite",
        "group": "Garnets & olivines",
        "formula": "Mg9Si4O16(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "fa": {
        "name": "fayalite",
        "group": "Garnets & olivines",
        "formula": "Fe2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "fasp": {
        "name": "fayalite [spinel]",
        "group": "High-P phases",
        "formula": "Fe2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "fo": {
        "name": "forsterite",
        "group": "Garnets & olivines",
        "formula": "Mg2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "fosp": {
        "name": "forsterite [spinel]",
        "group": "High-P phases",
        "formula": "Mg2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "lrn": {
        "name": "larnite",
        "group": "Garnets & olivines",
        "formula": "Ca2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "mont": {
        "name": "monticellite",
        "group": "Garnets & olivines",
        "formula": "CaMgSiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "teph": {
        "name": "tephroite",
        "group": "Garnets & olivines",
        "formula": "Mn2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "and": {
        "name": "andalusite",
        "group": "Aluminosilicates",
        "formula": "Al2SiO5",
        "crystal_system": "",
        "other_info": "",
    },
    "ky": {
        "name": "kyanite",
        "group": "Aluminosilicates",
        "formula": "Al2SiO5",
        "crystal_system": "",
        "other_info": "",
    },
    "sill": {
        "name": "sillimanite",
        "group": "Aluminosilicates",
        "formula": "Al2SiO5",
        "crystal_system": "",
        "other_info": "",
    },
    "amul": {
        "name": "Al-mullite",
        "group": "Aluminosilicates",
        "formula": "Al2.5Si0.5O4.75",
        "crystal_system": "",
        "other_info": "",
    },
    "smul": {
        "name": "Si-mullite",
        "group": "Aluminosilicates",
        "formula": "Al2SiO5",
        "crystal_system": "",
        "other_info": "",
    },
    "fctd": {
        "name": "Fe-chloritoid",
        "group": "Aluminosilicates",
        "formula": "FeAl2SiO5(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "mctd": {
        "name": "Mg-chloritoid",
        "group": "Aluminosilicates",
        "formula": "MgAl2SiO5(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "mnctd": {
        "name": "Mn-chloritoid",
        "group": "Aluminosilicates",
        "formula": "MnAl2SiO5(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "fst": {
        "name": "Fe-staurolite",
        "group": "Aluminosilicates",
        "formula": "Fe4Al18Si7.5O44(OH)4",
        "crystal_system": "",
        "other_info": "",
    },
    "mst": {
        "name": "Mg-staurolite",
        "group": "Aluminosilicates",
        "formula": "Mg4Al18Si7.5O44(OH)4",
        "crystal_system": "",
        "other_info": "",
    },
    "mnst": {
        "name": "Mn-staurolite",
        "group": "Aluminosilicates",
        "formula": "Mn4Al18Si7.5O44(OH)4",
        "crystal_system": "",
        "other_info": "",
    },
    "tpz": {
        "name": "hydroxy-topaz",
        "group": "Aluminosilicates",
        "formula": "Al2SiO4(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "ak": {
        "name": "akermanite",
        "group": "Other orthosilicates",
        "formula": "Ca2MgSi2O7",
        "crystal_system": "",
        "other_info": "",
    },
    "geh": {
        "name": "gehlenite",
        "group": "Other orthosilicates",
        "formula": "Ca2Al2SiO7",
        "crystal_system": "",
        "other_info": "",
    },
    "jgd": {
        "name": "julgoldite [FeFe]",
        "group": "Other orthosilicates",
        "formula": "Ca4Fe6Si6O21(OH)7",
        "crystal_system": "",
        "other_info": "",
    },
    "merw": {
        "name": "merwinite",
        "group": "Other orthosilicates",
        "formula": "Ca3MgSi2O8",
        "crystal_system": "",
        "other_info": "",
    },
    "mpm": {
        "name": "pumpellyite [MgAl]",
        "group": "Other orthosilicates",
        "formula": "Ca4MgAl5Si6O21(OH)7",
        "crystal_system": "",
        "other_info": "",
    },
    "fpm": {
        "name": "pumpellyite [FeAl]",
        "group": "Other orthosilicates",
        "formula": "Ca4FeAl5Si6O21(OH)7",
        "crystal_system": "",
        "other_info": "",
    },
    "rnk": {
        "name": "rankinite",
        "group": "Other orthosilicates",
        "formula": "Ca3Si2O7",
        "crystal_system": "",
        "other_info": "",
    },
    "tit": {
        "name": "titanite",
        "group": "Other orthosilicates",
        "formula": "CaTiSiO5",
        "crystal_system": "",
        "other_info": "",
    },
    "sph": {
        "name": "sphene",
        "group": "Other orthosilicates",
        "formula": "CaTiSiO5",
        "crystal_system": "",
        "other_info": "",
    },
    "spu": {
        "name": "spurrite",
        "group": "Other orthosilicates",
        "formula": "Ca5Si2CO11",
        "crystal_system": "",
        "other_info": "",
    },
    "ty": {
        "name": "tilleyite",
        "group": "Other orthosilicates",
        "formula": "Ca5Si2C2O13",
        "crystal_system": "",
        "other_info": "",
    },
    "zrc": {
        "name": "zircon",
        "group": "Other orthosilicates",
        "formula": "ZrSiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "cz": {
        "name": "clinozoisite",
        "group": "Sorosilicates",
        "formula": "Ca2Al3Si3O12(OH)",
        "crystal_system": "",
        "other_info": "",
    },
    "ep": {
        "name": "epidote [ordered]",
        "group": "Sorosilicates",
        "formula": "Ca2FeAl2Si3O12(OH)",
        "crystal_system": "",
        "other_info": "",
    },
    "fep": {
        "name": "Fe-epidote",
        "group": "Sorosilicates",
        "formula": "Ca2Fe2AlSi3O12(OH)",
        "crystal_system": "",
        "other_info": "",
    },
    "law": {
        "name": "lawsonite",
        "group": "Sorosilicates",
        "formula": "CaAl2Si2O6(OH)4",
        "crystal_system": "",
        "other_info": "",
    },
    "pmt": {
        "name": "piemontite [ordered]",
        "group": "Sorosilicates",
        "formula": "Ca2MnAl2Si3O12(OH)",
        "crystal_system": "",
        "other_info": "",
    },
    "zo": {
        "name": "zoisite",
        "group": "Sorosilicates",
        "formula": "Ca2Al3Si3O12(OH)",
        "crystal_system": "",
        "other_info": "",
    },
    "vsv": {
        "name": "vesuvianite",
        "group": "Sorosilicates",
        "formula": "Ca19Mg2Al11Si18O69(OH)9",
        "crystal_system": "",
        "other_info": "",
    },
    "crd": {
        "name": "cordierite",
        "group": "Cyclosilicates",
        "formula": "Mg2Al4Si5O18",
        "crystal_system": "",
        "other_info": "",
    },
    "hcrd": {
        "name": "hydrous-cordierite",
        "group": "Cyclosilicates",
        "formula": "Mg2Al4Si5O17(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "fcrd": {
        "name": "Fe-cordierite",
        "group": "Cyclosilicates",
        "formula": "Fe2Al4Si5O18",
        "crystal_system": "",
        "other_info": "",
    },
    "mncrd": {
        "name": "Mn-cordierite",
        "group": "Cyclosilicates",
        "formula": "Mn2Al4Si5O18",
        "crystal_system": "",
        "other_info": "",
    },
    "osm1": {
        "name": "osumilite [I]",
        "group": "Cyclosilicates",
        "formula": "KMg2Al5Si10O30",
        "crystal_system": "",
        "other_info": "",
    },
    "osm2": {
        "name": "osumilite [II]",
        "group": "Cyclosilicates",
        "formula": "KMg3Al3Si11O30",
        "crystal_system": "",
        "other_info": "",
    },
    "fosm": {
        "name": "Fe-osumilite",
        "group": "Cyclosilicates",
        "formula": "KFe2Al5Si10O30",
        "crystal_system": "",
        "other_info": "",
    },
    "apv": {
        "name": "Al-perovskite",
        "group": "High-P phases",
        "formula": "AlAlO3",
        "crystal_system": "",
        "other_info": "",
    },
    "cpv": {
        "name": "Ca-perovskite",
        "group": "High-P phases",
        "formula": "CaSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "cstn": {
        "name": "CaSi-titanite",
        "group": "High-P phases",
        "formula": "CaSi2O5",
        "crystal_system": "",
        "other_info": "",
    },
    "fak": {
        "name": "Fe-akimotoite",
        "group": "High-P phases",
        "formula": "FeSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "fpv": {
        "name": "Fe-perovskite",
        "group": "High-P phases",
        "formula": "FeSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "frw": {
        "name": "Fe-ringwoodite",
        "group": "High-P phases",
        "formula": "Fe2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "fwd": {
        "name": "Fe-wadsleyite",
        "group": "High-P phases",
        "formula": "Fe2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "mak": {
        "name": "akimotoite",
        "group": "High-P phases",
        "formula": "MgSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "mpv": {
        "name": "Mg-perovskite",
        "group": "High-P phases",
        "formula": "MgSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "mrw": {
        "name": "Mg-ringwoodite",
        "group": "High-P phases",
        "formula": "Mg2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "mwd": {
        "name": "Mg-wadsleyite",
        "group": "High-P phases",
        "formula": "Mg2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "phA": {
        "name": "phaseA",
        "group": "High-P phases",
        "formula": "Mg7Si2O8(OH)6",
        "crystal_system": "",
        "other_info": "",
    },
    "acm": {
        "name": "acmite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "NaFeSi2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "caes": {
        "name": "Ca-eskola pyroxene",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "Ca0.5AlSi2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "cats": {
        "name": "Ca-tschermaks pyroxene",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "CaAl2SiO6",
        "crystal_system": "",
        "other_info": "",
    },
    "cen": {
        "name": "clino enstatite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "Mg2Si2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "di": {
        "name": "diopside",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "CaMgSi2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "en": {
        "name": "enstatite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "Mg2Si2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "fs": {
        "name": "ferrosilite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "Fe2Si2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "cfs": {
        "name": "clino ferrosilite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "Fe2Si2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "hed": {
        "name": "hedenbergite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "CaFeSi2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "hen": {
        "name": "Hi-P clinoenstatite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "Mg2Si2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "jd": {
        "name": "jadeite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "NaAlSi2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "kos": {
        "name": "kosmochlor",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "NaCrSi2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "mgts": {
        "name": "Mg-tschermaks pyroxene",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "MgAl2SiO6",
        "crystal_system": "",
        "other_info": "",
    },
    "pren": {
        "name": "protoenstatite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "Mg2Si2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "pswo": {
        "name": "pseudowollastonite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "CaSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "pxmn": {
        "name": "pyroxmangite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "MnSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "rhod": {
        "name": "rhodonite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "MnSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "wal": {
        "name": "walstromite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "CaSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "wo": {
        "name": "wollastonite",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "CaSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "anth": {
        "name": "anthophyllite",
        "group": "Amphibole",
        "formula": "Mg7Si8O22(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "cumm": {
        "name": "cummingtonite",
        "group": "Amphibole",
        "formula": "Mg7Si8O22(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "fact": {
        "name": "ferroactinolite",
        "group": "Amphibole",
        "formula": "Ca2Fe5Si8O22(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "fanth": {
        "name": "Fe-anthophyllite",
        "group": "Amphibole",
        "formula": "Fe7Si8O22(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "fgl": {
        "name": "ferroglaucophane",
        "group": "Amphibole",
        "formula": "Na2Fe3Al2Si8O22(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "gl": {
        "name": "glaucophane",
        "group": "Amphibole",
        "formula": "Na2Mg3Al2Si8O22(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "grun": {
        "name": "grunerite",
        "group": "Amphibole",
        "formula": "Fe7Si8O22(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "parg": {
        "name": "pargasite",
        "group": "Amphibole",
        "formula": "NaCa2Mg4Al3Si6O22(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "rieb": {
        "name": "riebeckite",
        "group": "Amphibole",
        "formula": "Na2Fe5Si8O22(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "tr": {
        "name": "tremolite",
        "group": "Amphibole",
        "formula": "Ca2Mg5Si8O22(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "ts": {
        "name": "tschermakite",
        "group": "Amphibole",
        "formula": "Ca2Mg3Al4Si6O22(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "deer": {
        "name": "deerite",
        "group": "Other chain silicates",
        "formula": "Fe18Si12O40(OH)10",
        "crystal_system": "",
        "other_info": "",
    },
    "fcar": {
        "name": "ferrocarpholite",
        "group": "Other chain silicates",
        "formula": "FeAl2Si2O6(OH)4",
        "crystal_system": "",
        "other_info": "",
    },
    "fspr": {
        "name": "Fe-sapphirine [221]",
        "group": "Other chain silicates",
        "formula": "Fe4Al8Si2O20",
        "crystal_system": "",
        "other_info": "",
    },
    "mcar": {
        "name": "magnesiocarpholite",
        "group": "Other chain silicates",
        "formula": "MgAl2Si2O6(OH)4",
        "crystal_system": "",
        "other_info": "",
    },
    "spr4": {
        "name": "sapphirine [221]",
        "group": "Other chain silicates",
        "formula": "Mg4Al8Si2O20",
        "crystal_system": "",
        "other_info": "",
    },
    "spr5": {
        "name": "sapphirine [351]",
        "group": "Other chain silicates",
        "formula": "Mg3Al10SiO20",
        "crystal_system": "",
        "other_info": "",
    },
    "ann": {
        "name": "annite",
        "group": "Micas",
        "formula": "KFe3AlSi3O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "cel": {
        "name": "celadonite",
        "group": "Micas",
        "formula": "KMgAlSi4O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "east": {
        "name": "eastonite",
        "group": "Micas",
        "formula": "KMg2Al3Si2O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "fcel": {
        "name": "ferroceladonite",
        "group": "Micas",
        "formula": "KFeAlSi4O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "ma": {
        "name": "margarite",
        "group": "Micas",
        "formula": "CaAl4Si2O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "mnbi": {
        "name": "Mn-biotite",
        "group": "Micas",
        "formula": "KMn3AlSi3O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "mu": {
        "name": "muscovite",
        "group": "Micas",
        "formula": "KAl3Si3O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "naph": {
        "name": "sodaphlogopite",
        "group": "Micas",
        "formula": "NaMg3AlSi3O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "pa": {
        "name": "paragonite",
        "group": "Micas",
        "formula": "NaAl3Si3O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "phl": {
        "name": "phlogopite",
        "group": "Micas",
        "formula": "KMg3AlSi3O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "afchl": {
        "name": "Al-free chlorite",
        "group": "Chlorites",
        "formula": "Mg6Si4O10(OH)8",
        "crystal_system": "",
        "other_info": "",
    },
    "ames": {
        "name": "amesite [14A]",
        "group": "Chlorites",
        "formula": "Mg4Al4Si2O10(OH)8",
        "crystal_system": "",
        "other_info": "",
    },
    "clin": {
        "name": "clinochlore [ordered]",
        "group": "Chlorites",
        "formula": "Mg5Al2Si3O10(OH)8",
        "crystal_system": "",
        "other_info": "",
    },
    "daph": {
        "name": "daphnite",
        "group": "Chlorites",
        "formula": "Fe5Al2Si3O10(OH)8",
        "crystal_system": "",
        "other_info": "",
    },
    "fsud": {
        "name": "ferrosudoite",
        "group": "Chlorites",
        "formula": "Fe2Al4Si3O10(OH)8",
        "crystal_system": "",
        "other_info": "",
    },
    "mnchl": {
        "name": "Mn-chlorite",
        "group": "Chlorites",
        "formula": "Mn5Al2Si3O10(OH)8",
        "crystal_system": "",
        "other_info": "",
    },
    "sud": {
        "name": "sudoite",
        "group": "Chlorites",
        "formula": "Mg2Al4Si3O10(OH)8",
        "crystal_system": "",
        "other_info": "",
    },
    "atg": {
        "name": "antigorite",
        "group": "Other sheet silicates",
        "formula": "Mg48Si34O85(OH)62",
        "crystal_system": "",
        "other_info": "",
    },
    "chr": {
        "name": "chrysotile",
        "group": "Other sheet silicates",
        "formula": "Mg3Si2O5(OH)4",
        "crystal_system": "",
        "other_info": "",
    },
    "fpre": {
        "name": "ferri-prehnite",
        "group": "Other sheet silicates",
        "formula": "Ca2FeAlSi3O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "fstp": {
        "name": "ferrostilpnomelane",
        "group": "Other sheet silicates",
        "formula": "K0.5Fe5Al2Si8O18(OH)12.5",
        "crystal_system": "",
        "other_info": "",
    },
    "fta": {
        "name": "ferrotalc",
        "group": "Other sheet silicates",
        "formula": "Fe3Si4O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "glt": {
        "name": "greenalite",
        "group": "Other sheet silicates",
        "formula": "Fe3Si2O5(OH)4",
        "crystal_system": "",
        "other_info": "",
    },
    "kao": {
        "name": "kaolinite",
        "group": "Other sheet silicates",
        "formula": "Al2Si2O5(OH)4",
        "crystal_system": "",
        "other_info": "",
    },
    "liz": {
        "name": "lizardite",
        "group": "Other sheet silicates",
        "formula": "Mg3Si2O5(OH)4",
        "crystal_system": "",
        "other_info": "",
    },
    "minm": {
        "name": "Mg-minnesotaite",
        "group": "Other sheet silicates",
        "formula": "Mg3Si4O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "minn": {
        "name": "minnesotaite",
        "group": "Other sheet silicates",
        "formula": "Fe3Si4O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "mstp": {
        "name": "Mg-stilpnomelane",
        "group": "Other sheet silicates",
        "formula": "K0.5Mg5Al2Si8O18(OH)12.5",
        "crystal_system": "",
        "other_info": "",
    },
    "pre": {
        "name": "prehnite",
        "group": "Other sheet silicates",
        "formula": "Ca2Al2Si3O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "prl": {
        "name": "pyrophyllite",
        "group": "Other sheet silicates",
        "formula": "Al2Si4O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "ta": {
        "name": "talc",
        "group": "Other sheet silicates",
        "formula": "Mg3Si4O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "tap": {
        "name": "prl-talc",
        "group": "Other sheet silicates",
        "formula": "Al2Si4O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "tats": {
        "name": "tschermak-talc",
        "group": "Other sheet silicates",
        "formula": "Mg2Al2Si3O10(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "abh": {
        "name": "albite [high]",
        "group": "Feldspars & feldspathoid",
        "formula": "NaAlSi3O8",
        "crystal_system": "",
        "other_info": "",
    },
    "ab": {
        "name": "albite",
        "group": "Feldspars & feldspathoid",
        "formula": "NaAlSi3O8",
        "crystal_system": "",
        "other_info": "",
    },
    "an": {
        "name": "anorthite",
        "group": "Feldspars & feldspathoid",
        "formula": "CaAl2Si2O8",
        "crystal_system": "",
        "other_info": "",
    },
    "anl": {
        "name": "analcite",
        "group": "Feldspars & feldspathoid",
        "formula": "NaAlSi2O5(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "cg": {
        "name": "carnegieite [low]",
        "group": "Feldspars & feldspathoid",
        "formula": "NaAlSiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "cgh": {
        "name": "carnegieite [high]",
        "group": "Feldspars & feldspathoid",
        "formula": "NaAlSiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "kcm": {
        "name": "K-cymrite",
        "group": "Feldspars & feldspathoid",
        "formula": "KAlSi3O7(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "kls": {
        "name": "kalsilite",
        "group": "Feldspars & feldspathoid",
        "formula": "KAlSiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "lc": {
        "name": "leucite",
        "group": "Feldspars & feldspathoid",
        "formula": "KAlSi2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "mic": {
        "name": "microcline",
        "group": "Feldspars & feldspathoid",
        "formula": "KAlSi3O8",
        "crystal_system": "",
        "other_info": "",
    },
    "ne": {
        "name": "nepheline",
        "group": "Feldspars & feldspathoid",
        "formula": "NaAlSiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "san": {
        "name": "sanidine",
        "group": "Feldspars & feldspathoid",
        "formula": "KAlSi3O8",
        "crystal_system": "",
        "other_info": "",
    },
    "coe": {
        "name": "coesite",
        "group": "Silica minerals",
        "formula": "SiO2",
        "crystal_system": "",
        "other_info": "",
    },
    "crst": {
        "name": "cristobalite [high]",
        "group": "Silica minerals",
        "formula": "SiO2",
        "crystal_system": "",
        "other_info": "",
    },
    "q": {
        "name": "quartz",
        "group": "Silica minerals",
        "formula": "SiO2",
        "crystal_system": "",
        "other_info": "",
    },
    "stv": {
        "name": "stishovite",
        "group": "Silica minerals",
        "formula": "SiO2",
        "crystal_system": "",
        "other_info": "",
    },
    "trd": {
        "name": "tridymite [high]",
        "group": "Silica minerals",
        "formula": "SiO2",
        "crystal_system": "",
        "other_info": "",
    },
    "heu": {
        "name": "heulandite",
        "group": "Other framework silicates",
        "formula": "CaAl2Si7O12(OH)12",
        "crystal_system": "",
        "other_info": "",
    },
    "hol": {
        "name": "hollandite",
        "group": "Other framework silicates",
        "formula": "KAlSi3O8",
        "crystal_system": "",
        "other_info": "",
    },
    "lmt": {
        "name": "laumontite",
        "group": "Other framework silicates",
        "formula": "CaAl2Si4O8(OH)8",
        "crystal_system": "",
        "other_info": "",
    },
    "me": {
        "name": "meionite",
        "group": "Other framework silicates",
        "formula": "Ca4Al6Si6CO27",
        "crystal_system": "",
        "other_info": "",
    },
    "sdl": {
        "name": "sodalite",
        "group": "Other framework silicates",
        "formula": "Na8Al6Si6O24Cl2",
        "crystal_system": "",
        "other_info": "",
    },
    "stlb": {
        "name": "stilbite",
        "group": "Other framework silicates",
        "formula": "CaAl2Si7O11(OH)14",
        "crystal_system": "",
        "other_info": "",
    },
    "wa": {
        "name": "Si-wadeite",
        "group": "Other framework silicates",
        "formula": "K2Si4O9",
        "crystal_system": "",
        "other_info": "",
    },
    "wrk": {
        "name": "wairakite",
        "group": "Other framework silicates",
        "formula": "CaAl2Si4O10(OH)4",
        "crystal_system": "",
        "other_info": "",
    },
    "bdy": {
        "name": "baddeleyite",
        "group": "Oxides",
        "formula": "ZrO2",
        "crystal_system": "",
        "other_info": "",
    },
    "bix": {
        "name": "bixbyite",
        "group": "Oxides",
        "formula": "Mn2O3",
        "crystal_system": "",
        "other_info": "",
    },
    "cor": {
        "name": "corundum",
        "group": "Oxides",
        "formula": "Al2O3",
        "crystal_system": "",
        "other_info": "",
    },
    "cup": {
        "name": "cuprite",
        "group": "Oxides",
        "formula": "Cu2O",
        "crystal_system": "",
        "other_info": "",
    },
    "esk": {
        "name": "eskolaite",
        "group": "Oxides",
        "formula": "Cr2O3",
        "crystal_system": "",
        "other_info": "",
    },
    "fper": {
        "name": "ferropericlase",
        "group": "Oxides",
        "formula": "FeO",
        "crystal_system": "",
        "other_info": "",
    },
    "geik": {
        "name": "geikielite",
        "group": "Oxides",
        "formula": "MgTiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "hem": {
        "name": "hematite",
        "group": "Oxides",
        "formula": "Fe2O3",
        "crystal_system": "",
        "other_info": "",
    },
    "herc": {
        "name": "hercynite",
        "group": "Oxides",
        "formula": "FeAl2O4",
        "crystal_system": "",
        "other_info": "",
    },
    "ilm": {
        "name": "ilmenite",
        "group": "Oxides",
        "formula": "FeTiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "lime": {
        "name": "lime",
        "group": "Oxides",
        "formula": "CaO",
        "crystal_system": "",
        "other_info": "",
    },
    "mang": {
        "name": "manganosite",
        "group": "Oxides",
        "formula": "MnO",
        "crystal_system": "",
        "other_info": "",
    },
    "mcor": {
        "name": "MgSi-corundum",
        "group": "Oxides",
        "formula": "MgSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "mft": {
        "name": "magnesioferrite",
        "group": "Oxides",
        "formula": "MgFe2O4",
        "crystal_system": "",
        "other_info": "",
    },
    "mt": {
        "name": "magnetite",
        "group": "Oxides",
        "formula": "Fe3O4",
        "crystal_system": "",
        "other_info": "",
    },
    "GeO2": {
        "name": "germanium oxide",
        "group": "Oxides",
        "formula": "GeO2",
        "crystal_system": "",
        "other_info": "",
    },
    "NiO": {
        "name": "nickel oxide",
        "group": "Oxides",
        "formula": "NiO",
        "crystal_system": "",
        "other_info": "",
    },
    "per": {
        "name": "periclase",
        "group": "Oxides",
        "formula": "MgO",
        "crystal_system": "",
        "other_info": "",
    },
    "picr": {
        "name": "picrochromite",
        "group": "Oxides",
        "formula": "MgCr2O4",
        "crystal_system": "",
        "other_info": "",
    },
    "pnt": {
        "name": "pyrophanite",
        "group": "Oxides",
        "formula": "MnTiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "pntpv": {
        "name": "pyrophanite [perovskite]",
        "group": "High-P phases",
        "formula": "MnTiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "ru": {
        "name": "rutile",
        "group": "Oxides",
        "formula": "TiO2",
        "crystal_system": "",
        "other_info": "",
    },
    "sp": {
        "name": "spinel",
        "group": "Oxides",
        "formula": "MgAl2O4",
        "crystal_system": "",
        "other_info": "",
    },
    "ten": {
        "name": "tenorite",
        "group": "Oxides",
        "formula": "CuO",
        "crystal_system": "",
        "other_info": "",
    },
    "usp": {
        "name": "ulvospinel",
        "group": "Oxides",
        "formula": "Fe2TiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "br": {
        "name": "brucite",
        "group": "Hydroxides",
        "formula": "Mg(OH)2",
        "crystal_system": "",
        "other_info": "",
    },
    "dsp": {
        "name": "diaspore",
        "group": "Hydroxides",
        "formula": "AlO(OH)",
        "crystal_system": "",
        "other_info": "",
    },
    "gth": {
        "name": "goethite",
        "group": "Hydroxides",
        "formula": "FeO(OH)",
        "crystal_system": "",
        "other_info": "",
    },
    "ank": {
        "name": "ankerite",
        "group": "Carbonates",
        "formula": "CaFe(CO3)2",
        "crystal_system": "",
        "other_info": "",
    },
    "arag": {
        "name": "aragonite",
        "group": "Carbonates",
        "formula": "CaCO3",
        "crystal_system": "",
        "other_info": "",
    },
    "cc": {
        "name": "calcite",
        "group": "Carbonates",
        "formula": "CaCO3",
        "crystal_system": "",
        "other_info": "",
    },
    "dol": {
        "name": "dolomite",
        "group": "Carbonates",
        "formula": "CaMg(CO3)2",
        "crystal_system": "",
        "other_info": "",
    },
    "mag": {
        "name": "magnesite",
        "group": "Carbonates",
        "formula": "MgCO3",
        "crystal_system": "",
        "other_info": "",
    },
    "rhc": {
        "name": "rhodochrosite",
        "group": "Carbonates",
        "formula": "MnCO3",
        "crystal_system": "",
        "other_info": "",
    },
    "sid": {
        "name": "siderite",
        "group": "Carbonates",
        "formula": "FeCO3",
        "crystal_system": "",
        "other_info": "",
    },
    "any": {
        "name": "anhydrite",
        "group": "Halides & sulphides",
        "formula": "CaSO4",
        "crystal_system": "",
        "other_info": "",
    },
    "hlt": {
        "name": "halite",
        "group": "Halides & sulphides",
        "formula": "NaCl",
        "crystal_system": "",
        "other_info": "",
    },
    "lot": {
        "name": "low troilite",
        "group": "Halides & sulphides",
        "formula": "FeS",
        "crystal_system": "",
        "other_info": "",
    },
    "pyr": {
        "name": "pyrite",
        "group": "Halides & sulphides",
        "formula": "FeS2",
        "crystal_system": "",
        "other_info": "",
    },
    "syv": {
        "name": "sylvite",
        "group": "Halides & sulphides",
        "formula": "KCl",
        "crystal_system": "",
        "other_info": "",
    },
    "tro": {
        "name": "troilite",
        "group": "Halides & sulphides",
        "formula": "FeS",
        "crystal_system": "",
        "other_info": "",
    },
    "trot": {
        "name": "pyrrhotite",
        "group": "Halides & sulphides",
        "formula": "FeS",
        "crystal_system": "",
        "other_info": "",
    },
    "trov": {
        "name": "pyrrhotite",
        "group": "Halides & sulphides",
        "formula": "Fe0.875S",
        "crystal_system": "",
        "other_info": "",
    },
    "Cu": {
        "name": "copper",
        "group": "Elements",
        "formula": "Cu",
        "crystal_system": "",
        "other_info": "",
    },
    "Pt": {
        "name": "platinum",
        "group": "Elements",
        "formula": "Pt",
        "crystal_system": "",
        "other_info": "",
    },
    "Zn": {
        "name": "zinc",
        "group": "Elements",
        "formula": "Zn",
        "crystal_system": "",
        "other_info": "",
    },
    "Pb": {
        "name": "lead",
        "group": "Elements",
        "formula": "Pb",
        "crystal_system": "",
        "other_info": "",
    },
    "Ag": {
        "name": "silver",
        "group": "Elements",
        "formula": "Ag",
        "crystal_system": "",
        "other_info": "",
    },
    "Au": {
        "name": "gold",
        "group": "Elements",
        "formula": "Au",
        "crystal_system": "",
        "other_info": "",
    },
    "Ge": {
        "name": "germanium",
        "group": "Elements",
        "formula": "Ge",
        "crystal_system": "",
        "other_info": "",
    },
    "diam": {
        "name": "diamond",
        "group": "Elements",
        "formula": "C",
        "crystal_system": "",
        "other_info": "",
    },
    "gph": {
        "name": "graphite",
        "group": "Elements",
        "formula": "C",
        "crystal_system": "",
        "other_info": "",
    },
    "iron": {
        "name": "iron",
        "group": "Elements",
        "formula": "Fe",
        "crystal_system": "",
        "other_info": "",
    },
    "Ni": {
        "name": "nickel",
        "group": "Elements",
        "formula": "Ni",
        "crystal_system": "",
        "other_info": "",
    },
    "S": {
        "name": "sulphur",
        "group": "Elements",
        "formula": "S",
        "crystal_system": "",
        "other_info": "",
    },
    "H2O": {
        "name": "water",
        "group": "Gas species",
        "formula": "H2O",
        "crystal_system": "",
        "other_info": "",
    },
    "CO2": {
        "name": "carbon dioxide",
        "group": "Gas species",
        "formula": "CO2",
        "crystal_system": "",
        "other_info": "",
    },
    "CO": {
        "name": "carbon monoxide",
        "group": "Gas species",
        "formula": "CO",
        "crystal_system": "",
        "other_info": "",
    },
    "CH4": {
        "name": "methane",
        "group": "Gas species",
        "formula": "CH4",
        "crystal_system": "",
        "other_info": "",
    },
    "O2": {
        "name": "oxygen",
        "group": "Gas species",
        "formula": "O2",
        "crystal_system": "",
        "other_info": "",
    },
    "H2": {
        "name": "hydrogen",
        "group": "Gas species",
        "formula": "H2",
        "crystal_system": "",
        "other_info": "",
    },
    "S2": {
        "name": "sulphur gas",
        "group": "Gas species",
        "formula": "S2",
        "crystal_system": "",
        "other_info": "",
    },
    "H2S": {
        "name": "hydrogen sulphide",
        "group": "Gas species",
        "formula": "H2S",
        "crystal_system": "",
        "other_info": "",
    },
    "abL": {
        "name": "albite liquid",
        "group": "Melt species",
        "formula": "NaAlSi3O8",
        "crystal_system": "",
        "other_info": "",
    },
    "anL": {
        "name": "anorthite liquid",
        "group": "Melt species",
        "formula": "CaAl2Si2O8",
        "crystal_system": "",
        "other_info": "",
    },
    "corL": {
        "name": "corundum liquid",
        "group": "Melt species",
        "formula": "Al2O3",
        "crystal_system": "",
        "other_info": "",
    },
    "diL": {
        "name": "diopside liquid",
        "group": "Melt species",
        "formula": "CaMgSi2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "enL": {
        "name": "enstatite liquid",
        "group": "Melt species",
        "formula": "Mg2Si2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "faL": {
        "name": "fayalite liquid",
        "group": "Melt species",
        "formula": "Fe2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "foL": {
        "name": "forsterite liquid",
        "group": "Melt species",
        "formula": "Mg2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "h2oL": {
        "name": "H2O liquid",
        "group": "Melt species",
        "formula": "H2O",
        "crystal_system": "",
        "other_info": "",
    },
    "hltL": {
        "name": "halite liquid",
        "group": "Melt species",
        "formula": "NaCl",
        "crystal_system": "",
        "other_info": "",
    },
    "kspL": {
        "name": "K-feldspar liquid",
        "group": "Melt species",
        "formula": "KAlSi3O8",
        "crystal_system": "",
        "other_info": "",
    },
    "lcL": {
        "name": "leucite liquid",
        "group": "Melt species",
        "formula": "KAlSi2O6",
        "crystal_system": "",
        "other_info": "",
    },
    "limL": {
        "name": "CaO liquid",
        "group": "Melt species",
        "formula": "CaO",
        "crystal_system": "",
        "other_info": "",
    },
    "neL": {
        "name": "nepheline liquid",
        "group": "Melt species",
        "formula": "NaAlSiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "perL": {
        "name": "MgO liquid",
        "group": "Melt species",
        "formula": "MgO",
        "crystal_system": "",
        "other_info": "",
    },
    "qL": {
        "name": "quartz liquid",
        "group": "Melt species",
        "formula": "SiO2",
        "crystal_system": "",
        "other_info": "",
    },
    "silL": {
        "name": "sillimanite liquid",
        "group": "Melt species",
        "formula": "Al2SiO5",
        "crystal_system": "",
        "other_info": "",
    },
    "syvL": {
        "name": "sylvite liquid",
        "group": "Melt species",
        "formula": "KCl",
        "crystal_system": "",
        "other_info": "",
    },
    "woL": {
        "name": "wollastonite liquid",
        "group": "Melt species",
        "formula": "CaSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "melt": {
        "name": "silicate melt",
        "group": "Melt species",
        "formula": "melt",
        "crystal_system": "",
        "other_info": "",
    },
    "H+": {
        "name": "hydrogen ion",
        "group": "Aqueous species",
        "formula": "H+",
        "crystal_system": "",
        "other_info": "",
    },
    "Cl-": {
        "name": "chloride ion",
        "group": "Aqueous species",
        "formula": "Cl−",
        "crystal_system": "",
        "other_info": "",
    },
    "OH-": {
        "name": "hydroxyl ion",
        "group": "Aqueous species",
        "formula": "HO−",
        "crystal_system": "",
        "other_info": "",
    },
    "Na+": {
        "name": "sodium ion",
        "group": "Aqueous species",
        "formula": "Na+",
        "crystal_system": "",
        "other_info": "",
    },
    "K+": {
        "name": "potassium ion",
        "group": "Aqueous species",
        "formula": "K+",
        "crystal_system": "",
        "other_info": "",
    },
    "Ca++": {
        "name": "calcium ion",
        "group": "Aqueous species",
        "formula": "Ca++",
        "crystal_system": "",
        "other_info": "",
    },
    "Mg++": {
        "name": "magnesium ion",
        "group": "Aqueous species",
        "formula": "Mg++",
        "crystal_system": "",
        "other_info": "",
    },
    "Fe++": {
        "name": "ferrous ion",
        "group": "Aqueous species",
        "formula": "Fe++",
        "crystal_system": "",
        "other_info": "",
    },
    "Al+++": {
        "name": "aluminium ion",
        "group": "Aqueous species",
        "formula": "Al+++",
        "crystal_system": "",
        "other_info": "",
    },
    "CO3-": {
        "name": "carbonate ion",
        "group": "Aqueous species",
        "formula": "CO3--",
        "crystal_system": "",
        "other_info": "",
    },
    "AlOH3": {
        "name": "aluminium hydroxide",
        "group": "Aqueous species",
        "formula": "Al(OH)3",
        "crystal_system": "",
        "other_info": "",
    },
    "AlOH4-": {
        "name": "aluminium hydroxide",
        "group": "Aqueous species",
        "formula": "Al(OH)4-",
        "crystal_system": "",
        "other_info": "",
    },
    "KOH": {
        "name": "potassium hydroxide",
        "group": "Aqueous species",
        "formula": "K(OH)",
        "crystal_system": "",
        "other_info": "",
    },
    "HCl": {
        "name": "hydrogen chloride",
        "group": "Aqueous species",
        "formula": "HCl",
        "crystal_system": "",
        "other_info": "",
    },
    "KCl": {
        "name": "potassium chloride",
        "group": "Aqueous species",
        "formula": "KCl",
        "crystal_system": "",
        "other_info": "",
    },
    "NaCl": {
        "name": "sodium chloride",
        "group": "Aqueous species",
        "formula": "NaCl",
        "crystal_system": "",
        "other_info": "",
    },
    "CaCl2": {
        "name": "calcium chloride",
        "group": "Aqueous species",
        "formula": "CaCl2",
        "crystal_system": "",
        "other_info": "",
    },
    "CaCl+": {
        "name": "calcium chloride",
        "group": "Aqueous species",
        "formula": "CaCl+",
        "crystal_system": "",
        "other_info": "",
    },
    "MgCl2": {
        "name": "magnesium chloride",
        "group": "Aqueous species",
        "formula": "MgCl2",
        "crystal_system": "",
        "other_info": "",
    },
    "MgCl+": {
        "name": "magnesium chloride",
        "group": "Aqueous species",
        "formula": "MgCl+",
        "crystal_system": "",
        "other_info": "",
    },
    "FeCl2": {
        "name": "ferrous chloride",
        "group": "Aqueous species",
        "formula": "FeCl2",
        "crystal_system": "",
        "other_info": "",
    },
    "aqSi": {
        "name": "silica [aq]",
        "group": "Aqueous species",
        "formula": "SiO2",
        "crystal_system": "",
        "other_info": "",
    },
    "HS-": {
        "name": "sulphide [aq]",
        "group": "Aqueous species",
        "formula": "HS-",
        "crystal_system": "",
        "other_info": "",
    },
    "HSO3-": {
        "name": "sulphite [aq]",
        "group": "Aqueous species",
        "formula": "HSO3-",
        "crystal_system": "",
        "other_info": "",
    },
    "SO4--": {
        "name": "sulphate [aq]",
        "group": "Aqueous species",
        "formula": "SO4--",
        "crystal_system": "",
        "other_info": "",
    },
    "HSO4-": {
        "name": "sulphate2 [aq]",
        "group": "Aqueous species",
        "formula": "HSO4-",
        "crystal_system": "",
        "other_info": "",
    },
    "cdgepx": {
        "name": "cadmium germinate [pyroxene]",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "CdGeO3",
        "crystal_system": "",
        "other_info": "",
    },
    "cdgegt": {
        "name": "cadmium germinate [garnet]",
        "group": "Garnets & olivines",
        "formula": "CdGeO3",
        "crystal_system": "",
        "other_info": "",
    },
    "cdgeilm": {
        "name": "cadmium germinate [ilmenite]",
        "group": "High-P phases",
        "formula": "CdGeO3",
        "crystal_system": "",
        "other_info": "",
    },
    "cdgepv": {
        "name": "cadmium germinate [perovskite]",
        "group": "High-P phases",
        "formula": "CdGeO3",
        "crystal_system": "",
        "other_info": "",
    },
    "cdgewo": {
        "name": "cadmium germinate [wollastonite]",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "CdGeO3",
        "crystal_system": "",
        "other_info": "",
    },
    "mggeol": {
        "name": "magnesium germinate [olivine]",
        "group": "Garnets & olivines",
        "formula": "Mg2GeO4",
        "crystal_system": "",
        "other_info": "",
    },
    "mggesp": {
        "name": "magnesium germinate [spinel]",
        "group": "Garnets & olivines",
        "formula": "Mg2GeO4",
        "crystal_system": "",
        "other_info": "",
    },
    "mggecpx": {
        "name": "magnesium germinate [clinopyroxene]",
        "group": "Pyroxenes & pyroxenoids",
        "formula": "MgGeO3",
        "crystal_system": "",
        "other_info": "",
    },
    "mggeilm": {
        "name": "magnesium germinate [ilmenite]",
        "group": "High-P phases",
        "formula": "MgGeO3",
        "crystal_system": "",
        "other_info": "",
    },
    "triple": {
        "name": "triple point",
        "group": "Aluminosilicates",
        "formula": "Al2SiO5",
        "crystal_system": "",
        "other_info": "",
    },
    "niol": {
        "name": "nickel silicate [olivine]",
        "group": "High-P phases",
        "formula": "Ni2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "nisp": {
        "name": "nickel silicate [spinel]",
        "group": "High-P phases",
        "formula": "Ni2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "cool": {
        "name": "cobalt silicate [olivine]",
        "group": "High-P phases",
        "formula": "Co2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "cosp": {
        "name": "cobalt silicate [spinel]",
        "group": "High-P phases",
        "formula": "Co2SiO4",
        "crystal_system": "",
        "other_info": "",
    },
    "coopx": {
        "name": "cobalt silicate [orthopyroxene]",
        "group": "High-P phases",
        "formula": "CoSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "cocpx": {
        "name": "cobalt silicate [clinopyroxene]",
        "group": "High-P phases",
        "formula": "CoSiO3",
        "crystal_system": "",
        "other_info": "",
    },
    "PbO2": {
        "name": "lead oxide",
        "group": "Oxides",
        "formula": "PbO2",
        "crystal_system": "",
        "other_info": "",
    },
    "irpv": {
        "name": "calcium-iridium perovskite",
        "group": "High-P phases",
        "formula": "CaIrO3",
        "crystal_system": "",
        "other_info": "",
    },
    "irppv": {
        "name": "calcium-iridium post-perovskite",
        "group": "High-P phases",
        "formula": "CaIrO3",
        "crystal_system": "",
        "other_info": "",
    },
    "nacopv": {
        "name": "sodium-cobalt perovskite",
        "group": "High-P phases",
        "formula": "NaCoF3",
        "crystal_system": "",
        "other_info": "",
    },
    "nacoppv": {
        "name": "sodium-cobalt post-perovskite",
        "group": "High-P phases",
        "formula": "NaCoF3",
        "crystal_system": "",
        "other_info": "",
    },
}
